<?php
/**
 * Initialize the custom theme options.
 */
add_action( 'admin_init', 'technews_custom_theme_options' );

/**
 * Build the custom settings & update OptionTree.
 */
function technews_custom_theme_options() {
  /**
   * Get a copy of the saved settings array. 
   */
  $saved_settings = get_option( 'option_tree_settings', array() );
  
  /**
   * Custom settings array that will eventually be 
   * passes to the OptionTree Settings API Class.
   */
  $custom_settings = array( 
    'contextual_help' => array( 
      'sidebar'       => ''
    ),
    'sections'        => array( 
      array(
        'id'          => 'social',
        'title'       => __( 'Social', 'technews' )
      ),
      array(
        'id'          => 'logo',
        'title'       => __( 'Logo', 'technews' )
      ),
      array(
        'id'          => 'favicon_setup',
        'title'       => __( 'Favicon', 'technews' )
      )
    ),
    'settings'        => array( 
      array(
        'id'          => 'facebook_url',
        'label'       => __( 'Facebook URL', 'technews' ),
        'desc'        => __( 'Enter your Facebook URL here along with http://', 'technews' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'social',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'google_plus_url',
        'label'       => __( 'Google Plus URL', 'technews' ),
        'desc'        => __( 'Enter your Google Plus URL here along with http://', 'technews' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'social',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'twitter_url',
        'label'       => __( 'Twitter URL', 'technews' ),
        'desc'        => __( 'Enter your Twitter URL here along with http://', 'technews' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'social',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'youtube_url',
        'label'       => __( 'YouTube URL', 'technews' ),
        'desc'        => __( 'Enter your YouTube URL here along with http://', 'technews' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'social',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'pinterest_url',
        'label'       => __( 'Pinterest URL', 'technews' ),
        'desc'        => __( 'Enter your Pinterest URL here along with http://', 'technews' ),
        'std'         => '',
        'type'        => 'text',
        'section'     => 'social',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'logo',
        'label'       => __( 'Change Logo', 'technews' ),
        'desc'        => __( 'Upload your logo.', 'technews' ),
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'logo',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'favicon',
        'label'       => __( 'Favicon', 'technews' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'favicon_setup',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      )
    )
  );
  
  /* allow settings to be filtered before saving */
  $custom_settings = apply_filters( 'option_tree_settings_args', $custom_settings );
  
  /* settings are not the same update the DB */
  if ( $saved_settings !== $custom_settings ) {
    update_option( 'option_tree_settings', $custom_settings ); 
  }
  
}